'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.response = undefined;

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _mkdirp = require('mkdirp');

var _fs = require('fs');

var _fs2 = _interopRequireDefault(_fs);

var _fsExtra = require('fs-extra');

var _lodash = require('lodash');

var _getEnvVar = require('get-env-var');

var _getEnvVar2 = _interopRequireDefault(_getEnvVar);

var _paths = require('../paths');

var _config = require('../config');

var config = _interopRequireWildcard(_config);

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) newObj[key] = obj[key]; } } newObj.default = obj; return newObj; } }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var alreadyAdded = 'alreadyAdded';
var success = 'success';
var fail = 'fail';
var unsupported = 'unsupported';

var response = exports.response = {
  alreadyAdded: alreadyAdded,
  success: success,
  fail: fail,
  unsupported: unsupported
};

exports.default = function (file, filePath) {
  (0, _mkdirp.sync)(_paths.appDir);

  var srcPath = null;
  var homePath = (0, _getEnvVar2.default)('HOME', '');
  switch (file) {
    case 'config':
      return unsupported;

    case 'bash_profile':
      srcPath = (0, _lodash.defaultTo)(filePath, _path2.default.join(homePath, '.bash_profile'));
      break;

    case 'bashrc':
      srcPath = (0, _lodash.defaultTo)(filePath, _path2.default.join(homePath, '.bashrc'));
      break;

    case 'vimrc':
      srcPath = (0, _lodash.defaultTo)(filePath, _path2.default.join(homePath, '.vimrc'));
      break;

    case 'gitconfig':
      srcPath = (0, _lodash.defaultTo)(filePath, _path2.default.join(homePath, '.gitconfig'));
      break;

    case 'zshrc':
      srcPath = (0, _lodash.defaultTo)(filePath, _path2.default.join(homePath, '.zshrc'));
      break;

    default:
      if (!filePath) return unsupported;
      srcPath = filePath;
  }

  if (!srcPath) return fail;

  (0, _fsExtra.ensureFileSync)(srcPath);

  if (_fs2.default.lstatSync(srcPath).isSymbolicLink()) {
    return alreadyAdded;
  }

  var addedFilePath = _path2.default.join(_paths.appDir, file);

  // replace original file with symlink
  if (config.getConfig('file.createBackup')) (0, _fsExtra.copySync)(srcPath, srcPath + '.bak');
  (0, _fsExtra.copySync)(srcPath, addedFilePath);
  (0, _fsExtra.removeSync)(srcPath);
  (0, _fsExtra.ensureSymlinkSync)(addedFilePath, srcPath);

  // add config
  config.setConfig('path.' + file, srcPath);

  return success;
};